library caris_controll_speed;

import 'dart:io' as io;
import 'dart:developer' as dv;
import 'package:caris_controll_speed/extension/string.dart';
import 'package:caris_controll_speed/model/max_speed_local.dart';
import 'package:caris_controll_speed/model/position.dart';
import 'package:flutter/services.dart';
import 'package:path/path.dart';
import 'package:sqflite/sqflite.dart';
import 'package:path_provider/path_provider.dart' as path_provider;

/// A Calculator.

class DataSQLite {
  Database? database;
  String? databasePath;

  Future<void> openSqliteInApp() async {
    // ignore: deprecated_member_use
    await Sqflite.devSetDebugModeOn(true);
    var appDocDir = await path_provider.getApplicationDocumentsDirectory();
    databasePath = join(appDocDir.path, 'max_speed_local.db');
    print(databasePath);

    bool dbExistsEnglish = await io.File(databasePath!).exists();
    if (!dbExistsEnglish) {
      ByteData data = await rootBundle.load('assets/max_speed.db');
      List<int> bytes =
          data.buffer.asUint8List(data.offsetInBytes, data.lengthInBytes);
      io.File maxSpeed = await io.File(databasePath!).writeAsBytes(bytes);
      databasePath = maxSpeed.path;
      print(databasePath);
    }
    database = await openDatabase(databasePath!);
  }

  Future<void> maxSpeedReload({
    required Position location,
    required List<MaxSpeedLocal> listMaxSpeed,
    required Function(List<MaxSpeedLocal>) updateListDataMaxSpeed,
  }) async {
    String sql =
        'SELECT * FROM coordinate_speed ${calculate4LocationInRadius(location)}';
    List<Map<String, Object?>> records = <Map<String, Object>>[];
    dv.log(sql);
    await database!.transaction((Transaction txn) async {
      records = await txn.rawQuery(sql);
      if (listMaxSpeed.isNotEmpty) {
        listMaxSpeed.clear();
        updateListDataMaxSpeed([]);
      }
      if (records.isNotEmpty) {
        listMaxSpeed = records.map((e) => MaxSpeedLocal.fromMap(e)).toList();
        updateListDataMaxSpeed(listMaxSpeed);
      }
      // dv.log('---------reload sql records-------${records.length}');
      // dv.log('---------reload sql records-------${listMaxSpeed.length}');
    });
  }
}
